#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_PIO_2_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_PIO_2_HPP_INCLUDED

#include <boost/simd/constant/include/constants/pio_2.hpp>

#endif
